#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import glob
import re

def convertInpFile(caseDir,modelName,solidName,density,dT,finalTime):
	inpFile = caseDir + '/' + modelName + '/CalculiXccxTools/FEMMeshGmsh.inp'
	f = open(inpFile)
	x = f.read()
	f.close()
	y = x.split('\n')
	# *英大文字で始まる
	deckCommand = r'^\*[A-Z]'
	# 数値で始まる
	deckNumData = r'^\d+'
	message = str(inpFile) + "を読み込みました。"
	print (message)

	inpFileName = caseDir + '/' + solidName + '.inp'
	namFileName = caseDir + '/interface.nam'

	is1=0; is2=0
	nodeList = []
	for i in range(len(y)):
		i = i + 1
		if ( y[i].strip() == '*CLOAD'):
			i = i + 1
			match = None
			while (match is None):
				# 数値で始まる（データ）カードを探す
				matchData = re.search(deckNumData, y[i]) 
				if matchData :
					# 見つかった数値をリスト（nodeList）に加える
					is1 = is1 + 1 ; nodeList.append(matchData.group(0))			
				i = i + 1
				# *英大文字で始まる（コマンド）カードを探す
				match = re.search( deckCommand, y[i] )
			break
	# 重複ノードを削除して順番に並び替える
	cNodeList = sorted(list(set(nodeList)), key=int )

	namFile = open(namFileName , 'w')
	namFile.writelines('*NSET,NSET=Nsurface\n')        

	for i in range(len(cNodeList)):
		namFile.writelines(cNodeList[i])
		namFile.writelines(',\n')
	namFile.close()

	inpFile = open(inpFileName , 'w')
	inpFile.writelines('*INCLUDE, INPUT=Solid/interface.nam\n')

	for i in range(len(y)):
		if ( y[i].strip() == '*ELASTIC'):
			# 追加行ナンバー(iDensity)を登録(*ELASTICカードの2行下)
			iDensity = i + 1
        
	for i in range(len(y)):
		if ( y[i].strip() == '*STEP'):
			# *STEPカードは書き換える
			y[i] = '*STEP, NLGEOM, INC=1000000'

	for i in range(len(y)):
			# *STATICカードは書き換える
		if ( y[i].strip() == '*STATIC'):
			y[i] = '*DYNAMIC, DIRECT'
			# 追加行ナンバー(iDynamic)を登録(*STATICカードの1行下)
			iDynamic = i

	for i in range(len(y)):
		if ( y[i].strip() == '*CLOAD'):
			# CLOADのデータカードから、
			# 次のコマンドカードが見つかるまでの
			# 位置（iCload〜iCload+j）を探す
			j = 1 ; iCload = i
			match = None
			while (match is None):
				j = j + 1
				# *英大文字で始まる（コマンド）カードを探す
				match = re.search( deckCommand, y[i+j] )
			break

	for i in range(len(y)):
		if( i <= iCload or i > iCload+j-4 ):		
			inpFile.writelines(y[i]+'\n')
			if ( i == iCload ):
				inpFile.writelines('Nsurface, 1, 0.0\n')
				inpFile.writelines('Nsurface, 2, 0.0\n')
				inpFile.writelines('Nsurface, 2, 0.0\n')
			if ( i == iDensity ):
				inpFile.writelines('*DENSITY\n')
				# 密度の値
				inpFile.writelines(str(density) + '\n')
			if ( i == iDynamic ):
				# 時間刻み、最終時刻の値
				inpFile.writelines(str(dT) + ', '+ str(finalTime) + '\n')
	
	inpFile.close()


def getSolver():
    solver = ""
    fileName = "./system/controlDict"
    if glob.glob(fileName) != "":
        f=open("./system/controlDict")
        for line in f.readlines():
            item = line.split()
            if len(item)>0:
                if item[0] == "application":
                    solver = line.split()[1]
                    break
    return solver


def getFoldersFiles(wdir):

	    folders = []
	    files = []
	    dirFiles = glob.glob(wdir + "/*")
	    for name in dirFiles:
	    	if os.path.isdir(name) == True:
	    		folders.append(name.split("/")[-1])
	    	elif os.path.isfile(name) == True:
	    		files.append(name.split("/")[-1])
	    folders.sort()
	    files.sort()
	    return [folders, files]


def caseFileDir(doc):

	name = os.path.splitext(doc.FileName)[0]
	modelDir = os.path.dirname(doc.FileName)

   
	#モデルファイル置き場がケースファイルの場所（.CaseFileDictで指定）と異なる場合
	caseFileDict = modelDir + "/.CaseFileDict"
	if os.path.isfile(caseFileDict) == True:
	    f = open(caseFileDict)
	    modelDir = f.read()
	    f.close()

	return modelDir


